declare('ChanColors', ChanColors or {})

ChanColors.version = 1.2

ChanColors.save_id = 42654226721

ChanColors.enabled = true
ChanColors.channels = {}
ChanColors.original_OnEvent = chatreceiver.OnEvent

function ChanColors.Load()
	ChanColors.channels = unspickle(LoadSystemNotes(ChanColors.save_id))
end

function ChanColors.Save()
	SaveSystemNotes(spickle(ChanColors.channels), ChanColors.save_id)
end

ChanColors.chatreceiver = {}
function ChanColors.chatreceiver:OnEvent(event, data)
	--data has msg, name, and faction, channelid (but not always!)
	if data ~= nil then
		if data.channelid ~= nil then
			local color = ChanColors.GetColor(data.channelid)
			if color ~= nil then
				data.msg = '\127' .. color .. data.msg
			end
		end
	end
	ChanColors:original_OnEvent(event, data)
end

function ChanColors.Enable()
	chatreceiver.OnEvent = ChanColors.chatreceiver.OnEvent
	ChanColors.enabled = true
	print('\127FFFFFFChanColors enabled')
end

function ChanColors.Disable()
	chatreceiver.OnEvent = ChanColors.original_OnEvent
	ChanColors.enabled = false
	print('\127FFFFFFChanColors disabled')
end

function ChanColors.Toggle()
	if ChanColors.enabled then
		ChanColors.Disable()
	else
		ChanColors.Enable()
	end
end

function ChanColors.GetColor(channelid)
	channelid = tonumber(channelid)
	if ChanColors.channels == nil then return nil end
	if ChanColors.channels[channelid] == nil then return nil end
	return(ChanColors.channels[channelid])
end

function ChanColors.SetColor(channelid, color)
	channelid = tonumber(channelid)
	ChanColors.channels[channelid] = color
	ChanColors.Save()
	ChanColors.Demo(channelid, color)
end

function ChanColors.UnsetColor(channelid)
	channelid = tonumber(channelid)
	ChanColors.channels[channelid] = nil
	ChanColors.Save()
end

function ChanColors.Clear()
	ChanColors.channels = {}
	ChanColors.Save()
end

function ChanColors.List()
	for channelid, color in pairs(ChanColors.channels) do
		ChanColors.Demo(channelid, color)
	end
end

function ChanColors.Demo(channelid, color)
	channelid = tonumber(channelid)
	print('\127FFFFFF[' .. channelid .. '] : ' .. color .. ' : ' .. '\127' .. color .. 'Sample text.')
end



function ChanColors.Usage()
	print('\127FFFFFFset\127A0A0A0 channelid color')
	print('\127FFFFFFunset\127A0A0A0 channelid')
	print('\127FFFFFFclearall')
	print('\127FFFFFFlist')
	print('\127FFFFFFenable')
	print('\127FFFFFFdisable')
	print('\127FFFFFFtoggle')
end


function ChanColors.Command(_,data)
	if (data == nil) then
		ChanColors.Usage()
	elseif (data[1] == "set") and data[2] ~= nil and data[3] ~= nil then
		ChanColors.SetColor(data[2], data[3])
	elseif (data[1] == "unset") and data[2] ~= nil then
		ChanColors.UnsetColor(data[2])
	elseif (data[1] == "clearall") then
		ChanColors.Clear()
	elseif (data[1] == "list") then
		ChanColors.List()
	elseif (data[1] == "enable") then
		ChanColors.Enable()
	elseif (data[1] == "disable") then
		ChanColors.Disable()
	elseif (data[1] == "toggle") then
		ChanColors.Toggle()
	else
		print('\127FF4040Error')
		ChanColors.Usage()
	end
end

RegisterUserCommand("ChanColors",ChanColors.Command)

ChanColors.Load()
ChanColors.Enable()


